#' @title Centromeric Mark data
#'
#' @docType data
#' @name cenmarkdata
NULL
#' @description bigdfDataCen: Example data for centromeric marks df with column OTU
#'
#' @format bigdfDataCen a data.frame with cols:
#' \describe{
#'   \item{OTU}{OTU, species, mandatory if in dfChrSize}
#'   \item{chrName}{name of chromosome}
#'   \item{markName}{name of mark (site)}
#' }
#' @seealso \code{\link{plotIdiograms}}
#' @seealso \code{\link{dfMarkColor}}
#' @seealso \code{\link{markpos}}
#' @seealso \code{\link{armRatioCI}}
#'
#' @rdname cenmarkdata
"bigdfDataCen"
#' @description dfOfCenMarks: Example data for centromeric marks
#'
#' @rdname cenmarkdata
"dfOfCenMarks"
#' @description allCenMarksSample: Example data for centromeric marks
#'
#' @rdname cenmarkdata
"allCenMarksSample"
